package com.huawei.location.lite.common.android.receiver;

import android.content.Intent;
import android.content.IntentFilter;
import android.text.TextUtils;
import com.huawei.location.lite.common.android.context.ContextUtil;
import com.huawei.location.lite.common.log.LogLocation;
import com.huawei.secure.android.common.intent.SafeIntent;
import com.huawei.secure.android.common.util.SafeString;
import java.util.List;
import java.util.concurrent.CopyOnWriteArrayList;
import java.util.concurrent.atomic.AtomicBoolean;

/* loaded from: PackageReceiver.class */
public class PackageReceiver extends SafeBroadcastReceiver {
    private static final String TAG = "PackageReceiver";
    private static final byte[] SYNC_LOCK = new byte[0];
    private static volatile PackageReceiver instance;
    AtomicBoolean isRegisterBr = new AtomicBoolean(false);
    private List<PackageOperateCallback> callbackList = new CopyOnWriteArrayList();

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v2, types: [byte[]] */
    /* JADX WARN: Type inference failed for: r0v3, types: [java.lang.Throwable] */
    /* JADX WARN: Type inference failed for: r0v5 */
    public static PackageReceiver getInstance() {
        if (instance == null) {
            ?? r0 = SYNC_LOCK;
            synchronized (r0) {
                if (instance == null) {
                    instance = new PackageReceiver();
                }
                r0 = r0;
            }
        }
        return instance;
    }

    private IntentFilter getPackageFilter() {
        IntentFilter intentFilter = new IntentFilter();
        intentFilter.addAction("android.intent.action.PACKAGE_REMOVED");
        intentFilter.addAction("android.intent.action.PACKAGE_ADDED");
        intentFilter.addAction("android.intent.action.PACKAGE_REPLACED");
        intentFilter.addDataScheme("package");
        return intentFilter;
    }

    public void registerCallback(PackageOperateCallback packageOperateCallback) {
        if (packageOperateCallback != null) {
            this.callbackList.add(packageOperateCallback);
        }
        if (!this.isRegisterBr.get()) {
            ContextUtil.getContext().registerReceiver(getInstance(), getPackageFilter());
            this.isRegisterBr.set(true);
        }
    }

    public void unregisterCallback(PackageOperateCallback packageOperateCallback) {
        if (packageOperateCallback != null) {
            this.callbackList.remove(packageOperateCallback);
        }
    }

    public void onSafeReceive(Intent intent) {
        if (intent == null) {
            LogLocation.e(TAG, "PackageReceiver receive null intent");
            return;
        }
        SafeIntent safeIntent = new SafeIntent(intent);
        String dataString = safeIntent.getDataString();
        String str = dataString;
        if (TextUtils.isEmpty(dataString)) {
            str = "";
        }
        String replace = SafeString.replace(str, "package:", "");
        if ("android.intent.action.PACKAGE_REMOVED".equals(safeIntent.getAction())) {
            LogLocation.d(TAG, "package_remove:" + replace);
            for (PackageOperateCallback packageOperateCallback : this.callbackList) {
                if (packageOperateCallback != null) {
                    packageOperateCallback.onRemoved(replace);
                }
            }
        } else if ("android.intent.action.PACKAGE_ADDED".equals(safeIntent.getAction())) {
            LogLocation.d(TAG, "package_add:" + replace);
            for (PackageOperateCallback packageOperateCallback2 : this.callbackList) {
                if (packageOperateCallback2 != null) {
                    packageOperateCallback2.onAdded(replace);
                }
            }
        } else if (!"android.intent.action.PACKAGE_REPLACED".equals(safeIntent.getAction())) {
            LogLocation.d(TAG, "action ===:" + safeIntent.getAction());
        } else {
            LogLocation.d(TAG, "package_replace:" + replace);
            for (PackageOperateCallback packageOperateCallback3 : this.callbackList) {
                if (packageOperateCallback3 != null) {
                    packageOperateCallback3.onReplaced(replace);
                }
            }
        }
    }

    public int threadExitDelayTime() {
        return 0;
    }

    public String receiveThreadName() {
        return "Loc_Package_Listener";
    }
}